@@ -23,6 +23,7 @@ sub import {
     base
     false
     from
+    mixin
     role
     test
     true
@@ -52,6 +53,9 @@ sub import {
   if ($exports{"raise"} && !*{"${from}::raise"}{"CODE"}) {
     *{"${from}::raise"} = sub ($;$) {require Venus; goto \&Venus::raise};
   }
+  if ($exports{"mixin"} && !*{"${from}::mixin"}{"CODE"}) {
+    *{"${from}::mixin"} = sub {@_ = ($from, @_); goto \&mixin};
+  }
   if ($exports{"role"} && !*{"${from}::role"}{"CODE"}) {
     *{"${from}::role"} = sub {@_ = ($from, @_); goto \&role};
   }
@@ -94,6 +98,14 @@ sub from {
   return $from;
 }
 
+sub mixin {
+  my ($from, @args) = @_;
+
+  $from->MIXIN(@args);
+
+  return $from;
+}
+
 sub role {
   my ($from, @args) = @_;
 
@@ -409,6 +421,87 @@ I<Since C<1.00>>
 
 =cut
 
+=head2 mixin
+
+  mixin(Str $name) (Str)
+
+The mixin function registers and consumes mixins for the calling package. This
+function is always exported unless a routine of the same name already exists.
+
+I<Since C<1.02>>
+
+=over 4
+
+=item mixin example 1
+
+  package YesNo;
+
+  use Venus::Mixin;
+
+  sub no {
+    return 0;
+  }
+
+  sub yes {
+    return 1;
+  }
+
+  sub EXPORT {
+    ['no', 'yes']
+  }
+
+  package Answer;
+
+  use Venus::Class;
+
+  mixin 'YesNo';
+
+  # "Answer"
+
+=back
+
+=over 4
+
+=item mixin example 2
+
+  package YesNo;
+
+  use Venus::Mixin;
+
+  sub no {
+    return 0;
+  }
+
+  sub yes {
+    return 1;
+  }
+
+  sub EXPORT {
+    ['no', 'yes']
+  }
+
+  package Answer;
+
+  use Venus::Class;
+
+  mixin 'YesNo';
+
+  sub no {
+    return [0];
+  }
+
+  sub yes {
+    return [1];
+  }
+
+  my $package = "Answer";
+
+  # "Answer"
+
+=back
+
+=cut
+
 =head2 raise
 
   raise(Str $class | Tuple[Str, Str] $class, Maybe[HashRef] $args) (Error)
