@@ -5,13 +5,14 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo;
+use Venus::Class;
 
-extends 'Venus::Kind::Value';
+base 'Venus::Kind::Value';
 
 use overload (
   '${}' => sub{$_[0]->value},
   '*{}' => sub{$_[0]->value},
+  fallback => 1,
 );
 
 # METHODS
